@@ -1253,3 +1253,24 @@ def iter_rotate_right(iterable, n, onlyfinal=False):
             yield iterable_
     if onlyfinal:
         yield iterable_
+
+
+def polymul(p, q):
+    """
+    Multiply two polynomials, represented as lists of coefficients.
+    """
+    r = [0] * (len(p) + len(q) - 1)
+    for i, c in enumerate(p):
+        for j, d in enumerate(q):
+            r[i + j] += c * d
+    return r
+
+
+def iter_number_of_combinations(it, k):
+    """
+    from https://stackoverflow.com/a/48612518/15096247
+    Number of combinations of length *k* of the elements of *it*.
+    """
+    counts = collections.Counter(it).values()
+    prod = reduce(polymul, [[1] * (count + 1) for count in counts], [1])
+    return prod[k] if k < len(prod) else 0
